// draw.cpp

#include "stdafx.h"
#include "cube.h"
#include "cDiaProprietes.h"

// dimension de la fenetre OpenGL
float w,h;

#define GL_PI 3.1415f

float ouverture=40;
float angleX=0,angleY=0,angleZ=0;
float transX=0,transY=0,transZ=-300;

extern cDiaProprietes *theDiaProp;

//----------------------------------------------------------

void drawScene(void)
	{
	GLfloat x,y,angle;  // Storage for coordinates and angles
	int iPivot = 1;		// Used to flag alternating colors

	// Clear the window and the depth buffer
	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);

	// Turn culling on if flag is set
	if(theDiaProp->m_culling)
		glEnable(GL_CULL_FACE);
	else
		glDisable(GL_CULL_FACE);

	// Enable depth testing if flag is set
	if(theDiaProp->m_depthTest)
		glEnable(GL_DEPTH_TEST);
	else
		glDisable(GL_DEPTH_TEST);

	// Draw back side as a polygon only, if flag is set
	if(!theDiaProp->m_fillPolygon)
	{
		glPolygonMode(GL_FRONT,GL_LINE);
	}
	else
		glPolygonMode(GL_FRONT,GL_FILL);
		

	// Save matrix state and do the rotation
	glPushMatrix();
	glTranslatef(transX,transY,transZ); // l'objet est repousse
	glRotatef(angleZ,0,0,1);
	glRotatef(angleY, 0.0f, 1.0f, 0.0f);
	glRotatef(angleX, 1.0f, 0.0f, 0.0f);


	// Begin a triangle fan
	glBegin(GL_TRIANGLE_FAN);

	// Pinnacle of cone is shared vertex for fan, moved up Z axis
	// to produce a cone instead of a circle
	glVertex3f(0.0f, 0.0f, 75.0f);
	
	for(angle = 0.0f; angle < (2.0f*GL_PI); angle += (GL_PI/8.0f))
		{
		// triangle fans sont  l'envers du bon sens!!!!!
		// Calculate x and y position of the next vertex
		x = 50.0f*sin(-angle);
		y = 50.0f*cos(-angle);
	
		// Alternate color between BLUE and green
		if((iPivot %2) == 0)
			glColor3f(0.0f, 1.0f, 0.5f);
		else
			glColor3f(0.0f, 0.0f, 1.0f);
			
		// Increment pivot to change color next time
		iPivot++;

		// Specify the next vertex for the triangle fan
		glVertex3f(x, y,0.0f);
		}

	// Done drawing fan for cone
	glEnd();


	// Begin a new triangle fan to cover the bottom
	glBegin(GL_TRIANGLE_FAN);

	// Center of fan is at the origin
	glVertex3f(0.0f, 0.0f,0.0f);
	for(angle = 0.0f; angle < (2.0f*GL_PI); angle += (GL_PI/8.0f))
		{
		// Calculate x and y position of the next vertex
		x = 50.0f*sin(angle);
		y = 50.0f*cos(angle);
	
		// Alternate color between red and green
		if((iPivot %2) == 0)
			glColor3f(0.0f, 1.0f, 0.0f);
		else
			glColor3f(1.0f, 0.0f, 0.0f);
			
		// Increment pivot to change color next time
		iPivot++;

		// Specify the next vertex for the triangle fan
		glVertex3f(x, y,0.0f);
		}

	// Done drawing the fan that covers the bottom
	glEnd();

	// Restore transformations
	glPopMatrix();
}

//----------------------------------------------------------

void setupGL()
{
	GLfloat nRange = 100.0f;
	float front=1,back=1000;

	// Prevent a divide by zero
	if(h == 0)
		h = 1;

	// Set Viewport to window dimensions
    glViewport(0, 0, w,h);

	// Reset projection matrix stack
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();

	// Reset Model view matrix stack
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
	gluPerspective(ouverture,w/h,front,back);	// Black background
	glClearColor(0.0f, 0.0f, 0.0f, 1.0f );

	// Set drawing color to green
	glColor3f(0.0f, 1.0f, 0.0f);

	glShadeModel(GL_FLAT);

	glFrontFace(GL_CCW);

	if(theDiaProp->m_front)
		glCullFace(GL_FRONT); // couper front polygon
	else
		glCullFace(GL_BACK);
}

//----------------------------------------------------------

void draw(int w0, int h0)
{
	w=w0;h=h0;

	setupGL();
	drawScene();
}

//----------------------------------------------------------
